package cn.com.ctop.kuaishou.modules.ai.controller;

import cn.com.ctop.common.module.utils.Check;
import cn.com.ctop.common.module.utils.QueryGenerator;
import cn.com.ctop.kuaishou.modules.ai.entity.KuaiShouAppMultipleBids;
import cn.com.ctop.kuaishou.modules.ai.service.IKuaiShouAppMultipleBidsService;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.util.oConvertUtils;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

/**
 * 多应用分别出价
 *
 * @author jeecg-boot
 * @version V1.0
 * @date 2021-05-18
 */
@Slf4j
@Api(tags = "多应用分别出价")
@RestController
@RequestMapping("/adsp/kuaiShouAppMultipleBids")
public class KuaiShouAppMultipleBidsController {
    @Autowired
    private IKuaiShouAppMultipleBidsService kuaiShouAppMultipleBidsService;

    /**
     * 分页列表查询
     *
     * @param kuaiShouAppMultipleBids
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    @ApiOperation(value = "多应用分别出价-分页列表查询", notes = "多应用分别出价-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPage<KuaiShouAppMultipleBids>> queryPageList(KuaiShouAppMultipleBids kuaiShouAppMultipleBids,
                                                                @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                                @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                                HttpServletRequest req) {
        Result<IPage<KuaiShouAppMultipleBids>> result = new Result<>();
        QueryWrapper<KuaiShouAppMultipleBids> queryWrapper = QueryGenerator.initQueryWrapper(kuaiShouAppMultipleBids, req.getParameterMap());
        Page<KuaiShouAppMultipleBids> page = new Page<KuaiShouAppMultipleBids>(pageNo, pageSize);
        IPage<KuaiShouAppMultipleBids> pageList = kuaiShouAppMultipleBidsService.page(page, queryWrapper);
        result.setSuccess(true);
        result.setSuccess(true);
        result.setResult(pageList);
        return result;
    }

    /**
     * 添加
     *
     * @param kuaiShouAppMultipleBids
     * @return
     */
    @ApiOperation(value = "多应用分别出价-添加", notes = "多应用分别出价-添加")
    @PostMapping(value = "/saveOrUpdate")
    public Result<KuaiShouAppMultipleBids> add(@RequestBody KuaiShouAppMultipleBids kuaiShouAppMultipleBids) {
        Result<KuaiShouAppMultipleBids> result = new Result<>();
        try {
            Long accountId = kuaiShouAppMultipleBids.getAccountId();
            Long appId = kuaiShouAppMultipleBids.getAppId();
            QueryWrapper<KuaiShouAppMultipleBids> appMultipleBidsQueryWrapper = new QueryWrapper<>();
            appMultipleBidsQueryWrapper.eq("account_id", accountId);
            appMultipleBidsQueryWrapper.eq("app_id", appId);
            appMultipleBidsQueryWrapper.orderByDesc("create_time");
            appMultipleBidsQueryWrapper.last("limit 1");
            KuaiShouAppMultipleBids one = kuaiShouAppMultipleBidsService.getOne(appMultipleBidsQueryWrapper);
            if (Check.isNull(one)) {
                kuaiShouAppMultipleBidsService.save(kuaiShouAppMultipleBids);
            } else {
                kuaiShouAppMultipleBids.setId(one.getId());
                kuaiShouAppMultipleBidsService.updateById(kuaiShouAppMultipleBids);
            }

            result.success("添加成功！");
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            result.error500("操作失败");
        }
        return result;
    }

    /**
     * 编辑
     *
     * @param kuaiShouAppMultipleBids
     * @return
     */
    @ApiOperation(value = "多应用分别出价-编辑", notes = "多应用分别出价-编辑")
    @PutMapping(value = "/edit")
    public Result<KuaiShouAppMultipleBids> edit(@RequestBody KuaiShouAppMultipleBids kuaiShouAppMultipleBids) {
        Result<KuaiShouAppMultipleBids> result = new Result<KuaiShouAppMultipleBids>();
        KuaiShouAppMultipleBids kuaiShouAppMultipleBidsEntity = kuaiShouAppMultipleBidsService.getById(kuaiShouAppMultipleBids.getId());
        if (kuaiShouAppMultipleBidsEntity == null) {
            result.error500("未找到对应实体");
        } else {
            boolean ok = kuaiShouAppMultipleBidsService.updateById(kuaiShouAppMultipleBids);
            if (ok) {
                result.success("修改成功!");
            }
        }

        return result;
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @ApiOperation(value = "多应用分别出价-通过id删除", notes = "多应用分别出价-通过id删除")
    @DeleteMapping(value = "/delete")
    public Result<?> delete(@RequestParam(name = "id") String id) {
        try {
            kuaiShouAppMultipleBidsService.removeById(id);
        } catch (Exception e) {
            log.error("删除失败", e.getMessage());
            return Result.error("删除失败!");
        }
        return Result.ok("删除成功!");
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @ApiOperation(value = "多应用分别出价-批量删除", notes = "多应用分别出价-批量删除")
    @DeleteMapping(value = "/deleteBatch")
    public Result<KuaiShouAppMultipleBids> deleteBatch(@RequestParam(name = "ids") String ids) {
        Result<KuaiShouAppMultipleBids> result = new Result<>();
        if (ids == null || "".equals(ids.trim())) {
            result.error500("参数不识别！");
        } else {
            this.kuaiShouAppMultipleBidsService.removeByIds(Arrays.asList(ids.split(",")));
            result.success("删除成功!");
        }
        return result;
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    @ApiOperation(value = "多应用分别出价-通过id查询", notes = "多应用分别出价-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<KuaiShouAppMultipleBids> queryById(@RequestParam(name = "id", required = true) String id) {
        Result<KuaiShouAppMultipleBids> result = new Result<>();
        KuaiShouAppMultipleBids kuaiShouAppMultipleBids = kuaiShouAppMultipleBidsService.getById(id);
        if (kuaiShouAppMultipleBids == null) {
            result.error500("未找到对应实体");
        } else {
            result.setResult(kuaiShouAppMultipleBids);
            result.setSuccess(true);
        }
        return result;
    }

    /**
     * 导出excel
     *
     * @param request
     * @param response
     */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, HttpServletResponse response) {
        // Step.1 组装查询条件
        QueryWrapper<KuaiShouAppMultipleBids> queryWrapper = null;
        try {
            String paramsStr = request.getParameter("paramsStr");
            if (oConvertUtils.isNotEmpty(paramsStr)) {
                String deString = URLDecoder.decode(paramsStr, "UTF-8");
                KuaiShouAppMultipleBids kuaiShouAppMultipleBids = JSON.parseObject(deString, KuaiShouAppMultipleBids.class);
                queryWrapper = QueryGenerator.initQueryWrapper(kuaiShouAppMultipleBids, request.getParameterMap());
            }
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        }

        //Step.2 AutoPoi 导出Excel
        ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
        List<KuaiShouAppMultipleBids> pageList = kuaiShouAppMultipleBidsService.list(queryWrapper);
        //导出文件名称
        mv.addObject(NormalExcelConstants.FILE_NAME, "多应用分别出价列表");
        mv.addObject(NormalExcelConstants.CLASS, KuaiShouAppMultipleBids.class);
        mv.addObject(NormalExcelConstants.PARAMS, new ExportParams("多应用分别出价列表数据", "导出人:Jeecg", "导出信息"));
        mv.addObject(NormalExcelConstants.DATA_LIST, pageList);
        return mv;
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
        for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
            MultipartFile file = entity.getValue();
            ImportParams params = new ImportParams();
            params.setTitleRows(2);
            params.setHeadRows(1);
            params.setNeedSave(true);
            try {
                List<KuaiShouAppMultipleBids> listKuaiShouAppMultipleBidss = ExcelImportUtil.importExcel(file.getInputStream(), KuaiShouAppMultipleBids.class, params);
                kuaiShouAppMultipleBidsService.saveBatch(listKuaiShouAppMultipleBidss);
                return Result.ok("文件导入成功！数据行数:" + listKuaiShouAppMultipleBidss.size());
            } catch (Exception e) {
                log.error(e.getMessage(), e);
                return Result.error("文件导入失败:" + e.getMessage());
            } finally {
                try {
                    file.getInputStream().close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
        return Result.ok("文件导入失败！");
    }

}
