package cn.com.ctop.kuaishou.modules.ai.controller;

import cn.com.ctop.common.module.annotation.AutoLog;
import cn.com.ctop.common.module.utils.Check;
import cn.com.ctop.common.module.utils.QueryGenerator;
import cn.com.ctop.kuaishou.modules.ai.entity.KuaishouLandpagePackage;
import cn.com.ctop.kuaishou.modules.ai.service.IKuaishouLandpagePackageService;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.pagehelper.PageHelper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.util.oConvertUtils;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

/**
 * 落地页账户项目关联表
 *
 * @author jeecg-boot
 * @version V1.0
 * @date 2021-05-11
 */
@Slf4j
@Api(tags = "落地页账户项目关联表")
@RestController
@RequestMapping("/kuaishouLandpagePackage")
public class KuaishouLandpagePackageController {
    @Autowired
    private IKuaishouLandpagePackageService kuaishouLandpagePackageService;

    /**
     * 分页列表查询
     *
     * @param kuaishouLandpagePackage
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    @AutoLog(value = "落地页账户项目关联表-分页列表查询")
    @ApiOperation(value = "落地页账户项目关联表-分页列表查询", notes = "落地页账户项目关联表-分页列表查询")
    @GetMapping(value = "/list")
    public Result<Object> queryPageList(KuaishouLandpagePackage kuaishouLandpagePackage, @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo, @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize) {
        try {
            return kuaishouLandpagePackageService.queryPageList(kuaishouLandpagePackage, pageNo, pageSize);
        } catch (Exception e) {
            log.error("查询落地页列表异常", e);
        }
        return Result.error("查询落地页列表失败");
    }

    /**
     * 同步项目下落地页和账户关联数据
     *
     * @param
     * @return org.jeecg.common.api.vo.Result<java.lang.Object>
     * @throws
     * @author ZHAOXA
     */
    @GetMapping(value = "/synchronousData")
    public Result<Object> synchronousData(KuaishouLandpagePackage kuaishouLandpagePackage) {
        try {
            if (Check.isNull(kuaishouLandpagePackage.getProjectId())) {
                return Result.error("请选择项目");
            }
            return kuaishouLandpagePackageService.synchronousData(kuaishouLandpagePackage.getProjectId());
        } catch (Exception e) {
            log.error("同步落地页数据异常", e);
        }
        return Result.error("同步落地页数据失败");
    }

    /**
     * 查询相关账户
     *
     * @param
     * @return org.jeecg.common.api.vo.Result<java.lang.Object>
     * @throws
     * @author ZHAOXA
     */
    @GetMapping(value = "/getRelatedAccounts")
    public Result<Object> getRelatedAccounts(Long siteId, @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo, @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize) {
        try {
            if (Check.isNull(siteId)) {
                return Result.error("缺少参数");
            }
            PageHelper.startPage(pageNo, pageSize);
            return kuaishouLandpagePackageService.getRelatedAccounts(siteId);
        } catch (Exception e) {
            log.error("查询异常", e);
        }
        return Result.error("查询失败");

    }

    /**
     * 查询相关组
     *
     * @param
     * @return org.jeecg.common.api.vo.Result<java.lang.Object>
     * @throws
     * @author ZHAOXA
     */
    @GetMapping(value = "/getRelatedGroups")
    public Result<Object> getRelatedGroups(Long siteId, Long accountId, @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo, @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize) {
        try {
            if (Check.isNull(siteId)) {
                return Result.error("缺少参数");
            }
            PageHelper.startPage(pageNo, pageSize);
            return kuaishouLandpagePackageService.getRelatedGroups(siteId, accountId);
        } catch (Exception e) {
            log.error("查询异常", e);
        }
        return Result.error("查询失败");

    }

    /**
     * @param
     * @return org.jeecg.common.api.vo.Result<java.lang.Object>
     * @throws
     * @author ZHAOXA
     */
    @GetMapping(value = "/createLandPageAndUnit")
    public Result<Object> createLandPageAndUnit(Long siteId, Long creativeId, Long unitId, Long accountId) {
        try {
            kuaishouLandpagePackageService.createLandPageAndUnit(siteId, creativeId, unitId, accountId);
        } catch (Exception e) {
            log.error("查询异常", e);
        }
        return Result.ok("ok");

    }

    /**
     * 添加
     *
     * @param kuaishouLandpagePackage
     * @return
     */
    @AutoLog(value = "落地页账户项目关联表-添加")
    @ApiOperation(value = "落地页账户项目关联表-添加", notes = "落地页账户项目关联表-添加")
    @PostMapping(value = "/add")
    public Result<KuaishouLandpagePackage> add(@RequestBody KuaishouLandpagePackage kuaishouLandpagePackage) {
        Result<KuaishouLandpagePackage> result = new Result<>();
        try {
            kuaishouLandpagePackageService.save(kuaishouLandpagePackage);
            result.success("添加成功！");
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            result.error500("操作失败");
        }
        return result;
    }

    /**
     * 编辑
     *
     * @param kuaishouLandpagePackage
     * @return
     */
    @AutoLog(value = "落地页账户项目关联表-编辑")
    @ApiOperation(value = "落地页账户项目关联表-编辑", notes = "落地页账户项目关联表-编辑")
    @PutMapping(value = "/edit")
    public Result<KuaishouLandpagePackage> edit(@RequestBody KuaishouLandpagePackage kuaishouLandpagePackage) {
        Result<KuaishouLandpagePackage> result = new Result<KuaishouLandpagePackage>();
        KuaishouLandpagePackage kuaishouLandpagePackageEntity = kuaishouLandpagePackageService.getById(kuaishouLandpagePackage.getId());
        if (kuaishouLandpagePackageEntity == null) {
            result.error500("未找到对应实体");
        } else {
            boolean ok = kuaishouLandpagePackageService.updateById(kuaishouLandpagePackage);
            if (ok) {
                result.success("修改成功!");
            }
        }

        return result;
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "落地页账户项目关联表-通过id删除")
    @ApiOperation(value = "落地页账户项目关联表-通过id删除", notes = "落地页账户项目关联表-通过id删除")
    @DeleteMapping(value = "/delete")
    public Result<?> delete(@RequestParam(name = "id", required = true) String id) {
        try {
            kuaishouLandpagePackageService.removeById(id);
        } catch (Exception e) {
            log.error("删除失败", e.getMessage());
            return Result.error("删除失败!");
        }
        return Result.ok("删除成功!");
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "落地页账户项目关联表-批量删除")
    @ApiOperation(value = "落地页账户项目关联表-批量删除", notes = "落地页账户项目关联表-批量删除")
    @DeleteMapping(value = "/deleteBatch")
    public Result<KuaishouLandpagePackage> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        Result<KuaishouLandpagePackage> result = new Result<>();
        if (ids == null || "".equals(ids.trim())) {
            result.error500("参数不识别！");
        } else {
            this.kuaishouLandpagePackageService.removeByIds(Arrays.asList(ids.split(",")));
            result.success("删除成功!");
        }
        return result;
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    @AutoLog(value = "落地页账户项目关联表-通过id查询")
    @ApiOperation(value = "落地页账户项目关联表-通过id查询", notes = "落地页账户项目关联表-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<KuaishouLandpagePackage> queryById(@RequestParam(name = "id", required = true) String id) {
        Result<KuaishouLandpagePackage> result = new Result<>();
        KuaishouLandpagePackage kuaishouLandpagePackage = kuaishouLandpagePackageService.getById(id);
        if (kuaishouLandpagePackage == null) {
            result.error500("未找到对应实体");
        } else {
            result.setResult(kuaishouLandpagePackage);
            result.setSuccess(true);
        }
        return result;
    }

    /**
     * 导出excel
     *
     * @param request
     * @param response
     */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, HttpServletResponse response) {
        // Step.1 组装查询条件
        QueryWrapper<KuaishouLandpagePackage> queryWrapper = null;
        try {
            String paramsStr = request.getParameter("paramsStr");
            if (oConvertUtils.isNotEmpty(paramsStr)) {
                String deString = URLDecoder.decode(paramsStr, "UTF-8");
                KuaishouLandpagePackage kuaishouLandpagePackage = JSON.parseObject(deString, KuaishouLandpagePackage.class);
                queryWrapper = QueryGenerator.initQueryWrapper(kuaishouLandpagePackage, request.getParameterMap());
            }
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        }

        //Step.2 AutoPoi 导出Excel
        ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
        List<KuaishouLandpagePackage> pageList = kuaishouLandpagePackageService.list(queryWrapper);
        //导出文件名称
        mv.addObject(NormalExcelConstants.FILE_NAME, "落地页账户项目关联表列表");
        mv.addObject(NormalExcelConstants.CLASS, KuaishouLandpagePackage.class);
        mv.addObject(NormalExcelConstants.PARAMS, new ExportParams("落地页账户项目关联表列表数据", "导出人:Jeecg", "导出信息"));
        mv.addObject(NormalExcelConstants.DATA_LIST, pageList);
        return mv;
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
        for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
            MultipartFile file = entity.getValue();
            ImportParams params = new ImportParams();
            params.setTitleRows(2);
            params.setHeadRows(1);
            params.setNeedSave(true);
            try {
                List<KuaishouLandpagePackage> listKuaishouLandpagePackages = ExcelImportUtil.importExcel(file.getInputStream(), KuaishouLandpagePackage.class, params);
                kuaishouLandpagePackageService.saveBatch(listKuaishouLandpagePackages);
                return Result.ok("文件导入成功！数据行数:" + listKuaishouLandpagePackages.size());
            } catch (Exception e) {
                log.error(e.getMessage(), e);
                return Result.error("文件导入失败:" + e.getMessage());
            } finally {
                try {
                    file.getInputStream().close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
        return Result.ok("文件导入失败！");
    }

}
